@@ -37,7 +37,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "1.0.0"
+#define LIBGNUTLS_VERSION "1.0.1"
 
 #ifndef HAVE_SIZE_T
 # define HAVE_SIZE_T
@@ -319,6 +319,7 @@ int gnutls_credentials_clear( gnutls_session session);
 /* cred is a structure defined by the kx algorithm 
  */
 int gnutls_credentials_set( gnutls_session, gnutls_credentials_type type, void* cred);
+#define gnutls_cred_set	gnutls_credentials_set
 
 /* Credential structures for SRP - used in gnutls_credentials_set(); */
 
@@ -420,12 +421,12 @@ void gnutls_global_set_log_level( int level);
 int gnutls_dh_params_init( gnutls_dh_params*);
 void gnutls_dh_params_deinit( gnutls_dh_params);
 int gnutls_dh_params_import_raw(gnutls_dh_params dh_params, const gnutls_datum *prime,
-			const gnutls_datum* generator);
+	const gnutls_datum* generator);
 int gnutls_dh_params_import_pkcs3(gnutls_dh_params params, 
 	const gnutls_datum * pkcs3_params, gnutls_x509_crt_fmt format);
 int gnutls_dh_params_generate2(gnutls_dh_params params, int bits);
 int gnutls_dh_params_export_pkcs3( gnutls_dh_params params,
-	   gnutls_x509_crt_fmt format, unsigned char* params_data, size_t* params_data_size);
+	gnutls_x509_crt_fmt format, unsigned char* params_data, size_t* params_data_size);
 int gnutls_dh_params_export_raw(gnutls_dh_params params,
 	gnutls_datum * prime, gnutls_datum * generator, unsigned int *bits);
 
@@ -443,6 +444,11 @@ int gnutls_rsa_params_export_raw(gnutls_rsa_params params,
 	gnutls_datum * m, gnutls_datum *e,
 	gnutls_datum *d, gnutls_datum *p, gnutls_datum* q, 
 	gnutls_datum* u, unsigned int *bits);
+int gnutls_rsa_params_export_pkcs1( gnutls_rsa_params params,
+        gnutls_x509_crt_fmt format, unsigned char* params_data,
+        size_t* params_data_size);
+int gnutls_rsa_params_import_pkcs1(gnutls_rsa_params params,
+        const gnutls_datum * pkcs1_params, gnutls_x509_crt_fmt format);
 
 /* Session stuff
  */
