@@ -20,7 +20,7 @@
  */
 
 /* This file contains the types and prototypes for the X.509
- * certificate and CRL parsing functions.
+ * certificate and CRL handling functions.
  */
 
 #ifndef GNUTLS_X509_H
@@ -237,8 +237,8 @@ int gnutls_x509_crl_verify( gnutls_x509_crl crl,
 	unsigned int flags, unsigned int *verify);
 
 int gnutls_x509_crt_check_revocation(gnutls_x509_crt cert,
-					     gnutls_x509_crl * crl_list,
-					     int crl_list_length);
+	gnutls_x509_crl * crl_list,
+	int crl_list_length);
 
 int gnutls_x509_crt_get_fingerprint(gnutls_x509_crt cert, 
 	gnutls_digest_algorithm algo, void *buf,
@@ -291,6 +291,17 @@ int gnutls_x509_privkey_export_rsa_raw(gnutls_x509_privkey key,
 	gnutls_datum *d, gnutls_datum *p, gnutls_datum* q, 
 	gnutls_datum* u);
 
+/* signing stuff.
+ */
+int gnutls_x509_privkey_sign_data( gnutls_x509_privkey key, gnutls_digest_algorithm digest,
+	unsigned int flags, const gnutls_datum* data,
+	void* signature, size_t* signature_size);
+int gnutls_x509_privkey_verify_data( gnutls_x509_privkey key, unsigned int flags, 
+	const gnutls_datum* data, const gnutls_datum* signature);
+int gnutls_x509_crt_verify_data( gnutls_x509_crt crt, unsigned int flags, 
+	const gnutls_datum* data, const gnutls_datum* signature);
+
+
 /* Certificate request stuff
  */
 struct gnutls_x509_crq_int;
