@@ -86,9 +86,13 @@ int _gnutls_dh_generate_prime(GNUTLS_MPI * ret_g, GNUTLS_MPI * ret_n,
 	/* Calculate the size of a prime factor of (prime-1)/2.
 	 * This is a bad emulation of Michael Wiener's table
 	 */
-        qbits = 120 + (((bits / 256) - 1) * 20);
-                if (qbits & 1)          /* better have an even number */
- 	               qbits++;
+        if (bits < 256) qbits = bits/2;
+        else {
+	        qbits = 120 + (((bits / 256) - 1) * 20);
+	}
+
+        if (qbits & 1)          /* better have an even number */
+	        qbits++;
 
 	/* find a prime number of size bits.
 	 */
@@ -122,7 +126,7 @@ int _gnutls_dh_generate_prime(GNUTLS_MPI * ret_g, GNUTLS_MPI * ret_n,
 		result = GNUTLS_E_INTERNAL_ERROR;
 		goto cleanup;
 	}
-	
+
 	gcry_prime_release_factors (factors); factors = NULL;
 	
 	if (ret_g)
@@ -244,11 +248,13 @@ void gnutls_dh_params_deinit(gnutls_dh_params dh_params)
   **/
 int gnutls_dh_params_generate2(gnutls_dh_params params, unsigned int bits)
 {
+int ret;
 
-	if (_gnutls_dh_generate_prime(&params->_generator, 
-		&params->_prime, bits) < 0) {
+	ret = _gnutls_dh_generate_prime(&params->_generator, 
+		&params->_prime, bits);
+	if (ret < 0) {
 		gnutls_assert();
-		return GNUTLS_E_MEMORY_ERROR;
+		return ret;
 	}
 
 	return 0;
@@ -262,8 +268,6 @@ int gnutls_dh_params_generate2(gnutls_dh_params params, unsigned int bits)
   *
   * This function will extract the DHParams found in a PKCS3 formatted
   * structure. This is the format generated by "openssl dhparam" tool.
-  * The output will be allocated using gnutls_malloc() and will be put
-  * in prime and generator structures.
   *
   * If the structure is PEM encoded, it should have a header
   * of "BEGIN DH PARAMETERS".
@@ -468,7 +472,8 @@ int gnutls_dh_params_export_pkcs3( gnutls_dh_params params,
 			return GNUTLS_E_MEMORY_ERROR;
 		}
 
-		if ((result=asn1_der_coding( c2, "", tmp, &len, NULL)) != ASN1_SUCCESS) {
+		if ((result=asn1_der_coding( c2, "", tmp, &len, NULL)) != ASN1_SUCCESS) 
+		{
 			gnutls_assert();
 			gnutls_free( tmp);
 			asn1_delete_structure(&c2);
@@ -496,7 +501,7 @@ int gnutls_dh_params_export_pkcs3( gnutls_dh_params params,
 		if ((uint)result + 1 > *params_data_size) {
 			gnutls_assert();
 			gnutls_free(out);
-			*params_data_size = result;
+			*params_data_size = result + 1;
 			return GNUTLS_E_SHORT_MEMORY_BUFFER;
 		}
 
@@ -531,6 +536,13 @@ int gnutls_dh_params_export_raw(gnutls_dh_params params,
 
 	size_t size;
 
+	if (params->_generator == NULL ||
+		params->_prime == NULL) 
+	{
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+	
 	size = 0;
 	_gnutls_mpi_print(NULL, &size, params->_generator);
 
