@@ -31,6 +31,8 @@
 #include <dn.h>
 #include <mpi.h>
 #include <extensions.h>
+#include <sign.h>
+#include <verify.h>
 
 static int _encode_rsa( ASN1_TYPE* c2, GNUTLS_MPI* params);
 
@@ -256,7 +258,7 @@ static ASN1_TYPE decode_dsa_key( const gnutls_datum* raw_key,
   * @format: One of DER or PEM
   *
   * This function will convert the given DER or PEM encoded key
-  * to the native gnutls_x509_privkey format. The output will be stored in 'key'.
+  * to the native gnutls_x509_privkey format. The output will be stored in @key .
   *
   * If the key is PEM encoded it should have a header of "RSA PRIVATE KEY", or
   * "DSA PRIVATE KEY".
@@ -368,7 +370,7 @@ int gnutls_x509_privkey_import(gnutls_x509_privkey key, const gnutls_datum * dat
   * @u: holds the coefficient
   *
   * This function will convert the given RSA raw parameters
-  * to the native gnutls_x509_privkey format. The output will be stored in 'key'.
+  * to the native gnutls_x509_privkey format. The output will be stored in @key.
   * 
   **/
 int gnutls_x509_privkey_import_rsa_raw(gnutls_x509_privkey key, 
@@ -636,7 +638,7 @@ static int _encode_rsa( ASN1_TYPE* c2, GNUTLS_MPI* params)
 	/* Read all the sizes */
 	total = 0;
 	for (i=0;i<6;i++) {
-		_gnutls_mpi_print( NULL, &size[i], params[i]);
+		_gnutls_mpi_print_lz( NULL, &size[i], params[i]);
 		total += size[i];
 	}
 
@@ -678,10 +680,10 @@ static int _encode_rsa( ASN1_TYPE* c2, GNUTLS_MPI* params)
 
 
 	/* calculate exp's size */
-	_gnutls_mpi_print( NULL, &size[6], exp1);
+	_gnutls_mpi_print_lz( NULL, &size[6], exp1);
 	total += size[6];
 
-	_gnutls_mpi_print( NULL, &size[7], exp2);
+	_gnutls_mpi_print_lz( NULL, &size[7], exp2);
 	total += size[7];
 
 	/* Encoding phase.
@@ -703,14 +705,14 @@ static int _encode_rsa( ASN1_TYPE* c2, GNUTLS_MPI* params)
 	exp1_data = &all_data[size[5]];
 	exp2_data = &all_data[size[6]];
 
-	_gnutls_mpi_print( m_data, &tmp_size, params[0]);
-	_gnutls_mpi_print( pube_data, &tmp_size, params[1]);
-	_gnutls_mpi_print( prie_data, &tmp_size, params[2]);
-	_gnutls_mpi_print( p1_data, &tmp_size, params[3]);
-	_gnutls_mpi_print( p2_data, &tmp_size, params[4]);
-	_gnutls_mpi_print( u_data, &tmp_size, params[5]);
-	_gnutls_mpi_print( exp1_data, &tmp_size, exp1);
-	_gnutls_mpi_print( exp2_data, &tmp_size, exp2);
+	_gnutls_mpi_print_lz( m_data, &tmp_size, params[0]);
+	_gnutls_mpi_print_lz( pube_data, &tmp_size, params[1]);
+	_gnutls_mpi_print_lz( prie_data, &tmp_size, params[2]);
+	_gnutls_mpi_print_lz( p1_data, &tmp_size, params[3]);
+	_gnutls_mpi_print_lz( p2_data, &tmp_size, params[4]);
+	_gnutls_mpi_print_lz( u_data, &tmp_size, params[5]);
+	_gnutls_mpi_print_lz( exp1_data, &tmp_size, exp1);
+	_gnutls_mpi_print_lz( exp2_data, &tmp_size, exp2);
 
 	/* Ok. Now we have the data. Create the asn1 structures
 	 */	
@@ -953,3 +955,93 @@ cleanup:
 	_gnutls_free_datum( &der);
 	return result;
 }
+
+#ifdef ENABLE_PKI
+
+/**
+  * gnutls_x509_privkey_sign_data - This function will sign the given data using the private key params
+  * @key: Holds the key
+  * @digest: should be MD5 or SHA1
+  * @flags: should be 0 for now
+  * @data: holds the data to be signed
+  * @signature: will contain the signature
+  * @signature_size: holds the size of signature (and will be replaced by the new size)
+  *
+  * This function will sign the given data using a signature algorithm supported by
+  * the private key. Signature algorithms are always used together with a hash functions.
+  * Different hash functions may be used for the RSA algorithm, but only
+  * SHA-1 for the DSA keys.
+  *
+  * If the buffer provided is not long enough to hold the output, then
+  * GNUTLS_E_SHORT_MEMORY_BUFFER will be returned.
+  *
+  * In case of failure a negative value will be returned, and
+  * 0 on success.
+  *
+  **/
+int gnutls_x509_privkey_sign_data( gnutls_x509_privkey key, gnutls_digest_algorithm digest,
+	unsigned int flags, const gnutls_datum* data,
+	void* signature, size_t* signature_size)
+{
+int result;
+gnutls_datum sig = { NULL, 0 };
+
+	if (key == NULL) {
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+
+	result = _gnutls_x509_sign( data, digest, key, &sig);
+	if (result < 0) {
+		gnutls_assert();
+		return result;
+	}
+	
+	if (*signature_size < sig.size) {
+		*signature_size = sig.size;
+		_gnutls_free_datum( &sig);
+		return GNUTLS_E_SHORT_MEMORY_BUFFER;
+	}
+	
+	*signature_size = sig.size;
+	memcpy( signature, sig.data, sig.size);
+	
+	_gnutls_free_datum( &sig);
+
+	return 0;
+}
+
+/**
+  * gnutls_x509_privkey_verify_data - This function will verify the given signed data.
+  * @key: Holds the key
+  * @flags: should be 0 for now
+  * @data: holds the data to be signed
+  * @signature: contains the signature
+  *
+  * This function will verify the given signed data, using the parameters in the
+  * private key.
+  *
+  * In case of a verification failure 0 is returned, and
+  * 1 on success.
+  *
+  **/
+int gnutls_x509_privkey_verify_data( gnutls_x509_privkey key, unsigned int flags, 
+	const gnutls_datum* data, const gnutls_datum* signature)
+{
+int result;
+
+	if (key == NULL) {
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+
+	result = _gnutls_x509_privkey_verify_signature( data, signature, key);
+	if (result < 0) {
+		gnutls_assert();
+		return 0;
+	}
+	
+	return result;
+}
+
+#endif
