@@ -48,10 +48,10 @@ static void disable_optional_stuff( gnutls_x509_crt cert);
   * @oid: holds an Object Identifier in a null terminated string
   * @raw_flag: must be 0, or 1 if the data are DER encoded
   * @name: a pointer to the name
-  * @sizeof_name: holds the size of 'name'
+  * @sizeof_name: holds the size of @name
   *
   * This function will set the part of the name of the Certificate subject, specified
-  * by the given OID. 
+  * by the given OID. The input string should be ASCII or UTF-8 encoded.
   *
   * Some helper macros with popular OIDs can be found in gnutls/x509.h
   * With this function you can only set the known OIDs. You can test
@@ -79,10 +79,10 @@ int gnutls_x509_crt_set_dn_by_oid(gnutls_x509_crt crt, const char* oid,
   * @oid: holds an Object Identifier in a null terminated string
   * @raw_flag: must be 0, or 1 if the data are DER encoded
   * @name: a pointer to the name
-  * @sizeof_name: holds the size of 'name'
+  * @sizeof_name: holds the size of @name
   *
   * This function will set the part of the name of the Certificate issuer, specified
-  * by the given OID. 
+  * by the given OID. The input string should be ASCII or UTF-8 encoded.
   *
   * Some helper macros with popular OIDs can be found in gnutls/x509.h
   * With this function you can only set the known OIDs. You can test
@@ -90,6 +90,9 @@ int gnutls_x509_crt_set_dn_by_oid(gnutls_x509_crt crt, const char* oid,
   * not known (by gnutls) you should properly DER encode your data, and
   * call this function with raw_flag set.
   *
+  * Normally you do not need to call this function, since the signing
+  * operation will copy the signer's name as the issuer of the certificate.
+  *
   * Returns 0 on success.
   *
   **/
@@ -107,10 +110,11 @@ int gnutls_x509_crt_set_issuer_dn_by_oid(gnutls_x509_crt crt, const char* oid,
 /**
   * gnutls_x509_crt_set_version - This function will set the Certificate request version
   * @crt: should contain a gnutls_x509_crt structure
-  * @version: holds the version number. For X509v1 certificates must be 0.
+  * @version: holds the version number. For X.509v1 certificates must be 1.
   *
-  * This function will set the version of the certificate request. This
-  * must be zero.
+  * This function will set the version of the certificate. This
+  * must be one for X.509 version 1, and so on. Plain certificates without
+  * extensions must have version set to one.
   *
   * Returns 0 on success.
   *
@@ -118,7 +122,15 @@ int gnutls_x509_crt_set_issuer_dn_by_oid(gnutls_x509_crt crt, const char* oid,
 int gnutls_x509_crt_set_version(gnutls_x509_crt crt, unsigned int version)
 {
 int result;
-uint8 null = version;
+char null = version;
+
+	if (crt==NULL) {
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+
+	null -= 1;
+	if (null < 0) null = 0;
 
 	result = asn1_write_value( crt->cert, "tbsCertificate.version", &null, 1);
 	if (result != ASN1_SUCCESS) {
@@ -144,6 +156,11 @@ int gnutls_x509_crt_set_key(gnutls_x509_crt crt, gnutls_x509_privkey key)
 {
 int result;
 
+	if (crt==NULL) {
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+
 	result = _gnutls_x509_encode_and_copy_PKI_params( crt->cert,
 		"tbsCertificate.subjectPublicKeyInfo", key->pk_algorithm,
 		key->params, key->params_size);
@@ -172,6 +189,11 @@ int gnutls_x509_crt_set_crq(gnutls_x509_crt crt, gnutls_x509_crq crq)
 int result;
 int pk_algorithm;
 
+	if (crt==NULL || crq == NULL) {
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+
 	pk_algorithm = gnutls_x509_crq_get_pk_algorithm( crq, NULL);
 
 	if (pk_algorithm != GNUTLS_PK_RSA) {
@@ -212,6 +234,11 @@ int gnutls_x509_crt_set_ca_status(gnutls_x509_crt crt, unsigned int ca)
 int result;
 gnutls_datum der_data;
 
+	if (crt==NULL) {
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+
 	/* generate the extension.
 	 */
 	result = _gnutls_x509_ext_gen_basicConstraints( ca, &der_data);
@@ -253,6 +280,11 @@ gnutls_datum der_data;
 gnutls_datum dnsname;
 unsigned int critical;
 
+	if (crt==NULL) {
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+
 	/* Check if the extension already exists.
 	 */
 	result = _gnutls_x509_crt_get_extension(crt, "2.5.29.17", 0, &dnsname, &critical);
@@ -307,6 +339,11 @@ int result;
 gnutls_datum signature;
 const char* pk;
 
+	if (crt==NULL || issuer == NULL) {
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+
 	if (issuer_key->pk_algorithm != GNUTLS_PK_RSA) {
 		gnutls_assert();
 		return GNUTLS_E_UNIMPLEMENTED_FEATURE;
@@ -413,6 +450,11 @@ const char* pk;
   **/
 int gnutls_x509_crt_set_activation_time(gnutls_x509_crt cert, time_t act_time)
 {
+	if (cert==NULL) {
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+
 	return _gnutls_x509_set_time( cert->cert, "tbsCertificate.validity.notBefore", act_time);
 }
 
@@ -428,6 +470,10 @@ int gnutls_x509_crt_set_activation_time(gnutls_x509_crt cert, time_t act_time)
   **/
 int gnutls_x509_crt_set_expiration_time(gnutls_x509_crt cert, time_t exp_time)
 {
+	if (cert==NULL) {
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
 	return _gnutls_x509_set_time( cert->cert, "tbsCertificate.validity.notAfter", exp_time);
 }
 
@@ -450,6 +496,11 @@ int gnutls_x509_crt_set_serial(gnutls_x509_crt cert, const unsigned char* serial
 {
 	int ret;
 
+	if (cert==NULL) {
+		gnutls_assert();
+		return GNUTLS_E_INVALID_REQUEST;
+	}
+
 	if ((ret = asn1_write_value(cert->cert, "tbsCertificate.serialNumber", serial, serial_size)) < 0) 
 	{
 		gnutls_assert();
